@@ -569,20 +569,23 @@ void irreco_window_edit_main_menu_create(IrrecoWindowEdit * edit_window)
 			       GTK_BUTTON(edit_window->menu_save));
 	hildon_app_menu_append(HILDON_APP_MENU(edit_window->menu),
 			       GTK_BUTTON(edit_window->menu_controllers));
+	/* Enable back when hardkeys are fixed */
 	/*hildon_app_menu_append(HILDON_APP_MENU(edit_window->menu),
 			       GTK_BUTTON(edit_window->menu_hardkeys));*/
 	hildon_app_menu_append(HILDON_APP_MENU(edit_window->menu),
 			       GTK_BUTTON(edit_window->menu_background));
-	hildon_app_menu_append(HILDON_APP_MENU(edit_window->menu),
-			       GTK_BUTTON(edit_window->menu_devices));
-	hildon_app_menu_append(HILDON_APP_MENU(edit_window->menu),
-			       GTK_BUTTON(edit_window->menu_theme_manager));
+	/* Uncomment when..   never? */
+	/*hildon_app_menu_append(HILDON_APP_MENU(edit_window->menu),
+			       GTK_BUTTON(edit_window->menu_devices));*/
 	hildon_app_menu_append(HILDON_APP_MENU(edit_window->menu),
 			       GTK_BUTTON(edit_window->menu_download_lirc));
-	/*hildon_app_menu_append(HILDON_APP_MENU(edit_window->menu),
-			       GTK_BUTTON(edit_window->menu_download_irtrans));*/
 	hildon_app_menu_append(HILDON_APP_MENU(edit_window->menu),
 			       GTK_BUTTON(edit_window->menu_newbutton));
+	hildon_app_menu_append(HILDON_APP_MENU(edit_window->menu),
+			       GTK_BUTTON(edit_window->menu_theme_manager));
+	/* Enable when irtrans backend is ported */
+	/*hildon_app_menu_append(HILDON_APP_MENU(edit_window->menu),
+			       GTK_BUTTON(edit_window->menu_download_irtrans));*/
 
 	/* Show menu. */
 	hildon_window_set_app_menu(HILDON_WINDOW(edit_window->window),
